.. :changelog:

History
-------

2.1.0 (2024-05-16)
------------------

+ Switch to using pytest
+ Move to GitHub
+ Create first open source releases for PyPI
+ Add in typing

2.0.0 (2022-02-15)
------------------

+ Updated to Python3
+ Updated to use the wayfarer library

1.1.0 (2016-11-22)
------------------

+ Update to Python 2.7.12 (from 2.7.5)
+ Update to networkx 1.11 (from 1.9.1)
+ Update to pyshp 1.2.10 (from 1.2.1)
+ Update to shapely 1.5.17 (from 1.4.3)

1.0.0 (2015-12-12)
------------------

Initial release